==> ct-hayek-1.0.tar.gz: ct-hayek-1.0/ModelSwarm.h <==
// **********************************
// from basic code to apps: changing lines are delimited with
//                                             // +++++++ start
//                                             // +++++++ end
// **********************************

// ModelSwarm.h

#import "Agent.h"
#import "RuleMaster.h"
#import "RuleMaker.h"
#import "MatrixMult.h"
#import "VectorTransFunc.h"
#import "TransFunc.h"
#import "DataWarehouse.h"
#import <objectbase/Swarm.h>
#import <collections.h>
#import <simtools.h>      // necessary to invoke ObjectLoader
                          // and to use, with the 1.3.1 v. of Swarm,
                          // the ListShuffler protocol
#import <objectbase.h>    // needed by <ProbeMap> in ModelSwarm.m
#import <activity.h>

// +++++++ start
#import "ConsumerInterface.h"
#import "ProducerInterface.h"
// +++++++ end

@interface ModelSwarm: Swarm
{
  int

// +++++++ start
  consumerNumber,
  consumerInputNodeNumber, consumerHiddenNodeNumber, consumerOutputNodeNumber,
  producerNumber,
  producerInputNodeNumber, producerHiddenNodeNumber, producerOutputNodeNumber,
  patternNumberInVerificationSet, patternNumberInTrainingSet,
  epochNumberInEachTrainingCycle, epochGroups;
// +++++++ end

  RuleMaster * ruleMaster;
  RuleMaker * ruleMaker;

  MatrixMult * matrixMult;
  VectorTransFunc * vectorTransFunc;
  TransFunc * transFunc;

// +++++++ start
  id <List>  consumerList;
  id <List>  producerList;
  id <List>  agentList, agentInterfaceList;
  id <ListShuffler> listShuffler;
  id <Array> consumerArray;
  id <Array> producerArray;
  id <Index> consumerArrayIndex;
  id <Index> producerArrayIndex;
  id <Index> producerListIndex;
// +++++++ end

  id <ActionGroup> modelActions;
  id <Schedule> modelSchedule;

  float weightRange, eps, alpha;
  int usingRandomOrderInLearning,
      longTermLearningInCT_OnlyWithCompleteTrainingSet,
      useOutputsAsTargetsInCT_RelearningScheme;

  int agentsAreDisplayingData, readWeightsFromFile;
  int useEO_EP;
}


+ createBegin: aZone;
- createEnd;
- buildObjects;
- buildActions;
- activateIn: swarmContext;

- (int) getPatternNumberInVerificationSet;
- (int) currentEpochGroups;
- (int) getCurrentEpochGroup;

// +++++++ start
- (int) getConsumerNumber;
- (int) getProducerNumber;
- getList;
- getInterfaceList;
- getConsumerArrayIndex;
- getProducerArrayIndex;
// ++++++++ end

@end

==> ct-hayek-1.2.tar.gz: ct-hayek-1.2/ModelSwarm.h <==
// **********************************
// from basic code to apps: changing lines are delimited with
//                                             // +++++++ start
//                                             // +++++++ end
// **********************************

// ModelSwarm.h

#import "BPCTAgent.h"
#import "BPCTRuleMaster.h"
#import "BPCTRuleMaker.h"
#import "MatrixMult.h"
#import "VectorTransFunc.h"
#import "TransFunc.h"
#import "DataWarehouse.h"
#import <objectbase/Swarm.h>
#import <collections.h>
#import <simtools.h>      // necessary to invoke ObjectLoader
                          // and to use, with the 1.3.1 v. of Swarm,
                          // the ListShuffler protocol
#import <objectbase.h>    // needed by <ProbeMap> in ModelSwarm.m
#import <activity.h>

// +++++++ start
#import "ConsumerInterface.h"
#import "ProducerInterface.h"
// +++++++ end

@interface ModelSwarm: Swarm
{
  int

// +++++++ start
  agentNumber, consumerNumber,
  consumerInputNodeNumber, consumerHiddenNodeNumber, consumerOutputNodeNumber,
  producerNumber,
  producerInputNodeNumber, producerHiddenNodeNumber, producerOutputNodeNumber,
  patternNumberInVerificationSet, patternNumberInTrainingSet,
  epochNumberInEachTrainingCycle, epochGroups;
// +++++++ end

  BPCTRuleMaster * ruleMaster;
  BPCTRuleMaker * ruleMaker;

  MatrixMult * matrixMult;
  VectorTransFunc * vectorTransFunc;
  TransFunc * transFunc;

// +++++++ start
  id <List>  consumerList;
  id <List>  producerList;
  id <List>  agentList, agentInterfaceList;
  id <ListShuffler> listShuffler;
  id <Array> consumerArray;
  id <Array> producerArray;
  id <Array> agentArray;
  id <Index> consumerArrayIndex;
  id <Index> producerArrayIndex;
  id <Index> agentArrayIndex;
  id <Index> producerListIndex;
// +++++++ end

  id <ActionGroup> modelActions;
  id <Schedule> modelSchedule;

  float weightRange, eps, alpha;
  int usingRandomOrderInLearning,
      longTermLearningInCT_OnlyWithCompleteTrainingSet,
      useOutputsAsTargetsInCT_RelearningScheme;

  int agentsAreDisplayingData, readWeightsFromFile;
  int useEO_EP;
}


+ createBegin: aZone;
- createEnd;
- buildObjects;
- buildActions;
- activateIn: swarmContext;

- (int) getPatternNumberInVerificationSet;
- (int) currentEpochGroups;
- (int) getCurrentEpochGroup;

// +++++++ start
- (int) getConsumerNumber;
- (int) getProducerNumber;
- getList;
- getInterfaceList;
- getConsumerArrayIndex;
- getProducerArrayIndex;
// ++++++++ end

- openProbeTo: (int) ag;

@end
